@@ -16,15 +16,14 @@
 import itertools
 import weakref
 
+from zope.interface import Interface
 from zope.interface import implementer
 from zope.interface import providedBy
-from zope.interface import Interface
 from zope.interface import ro
+from zope.interface._compat import _normalize_name
+from zope.interface._compat import _use_c_impl
 from zope.interface.interfaces import IAdapterRegistry
 
-from zope.interface._compat import _normalize_name
-from zope.interface._compat import STRING_TYPES
-from zope.interface._compat import _use_c_impl
 
 __all__ = [
     'AdapterRegistry',
@@ -60,45 +59,49 @@ __all__ = [
 # ``tuple([t fon t in range(10)])``      ->  82ns
 # ``tuple(t for t in range(10))``        -> 177ns
 # ``tuple(map(lambda t: t, range(10)))`` -> 168ns
-#
 
-class BaseAdapterRegistry(object):
+
+class BaseAdapterRegistry:
     """
     A basic implementation of the data storage and algorithms required
     for a :class:`zope.interface.interfaces.IAdapterRegistry`.
 
     Subclasses can set the following attributes to control how the data
     is stored; in particular, these hooks can be helpful for ZODB
-    persistence. They can be class attributes that are the named (or similar) type, or
-    they can be methods that act as a constructor for an object that behaves
-    like the types defined here; this object will not assume that they are type
-    objects, but subclasses are free to do so:
+    persistence. They can be class attributes that are the named
+    (or similar) type, or they can be methods that act as a constructor
+    for an object that behaves like the types defined here; this object
+    will not assume that they are type objects, but subclasses are free
+    to do so:
 
     _sequenceType = list
       This is the type used for our two mutable top-level "byorder" sequences.
-      Must support mutation operations like ``append()`` and ``del seq[index]``.
-      These are usually small (< 10). Although at least one of them is
-      accessed when performing lookups or queries on this object, the other
-      is untouched. In many common scenarios, both are only required when
-      mutating registrations and subscriptions (like what
+      Must support mutation operations like ``append()`` and ``del
+      seq[index]``.  These are usually small (< 10). Although at least one of
+      them is accessed when performing lookups or queries on this object, the
+      other is untouched. In many common scenarios, both are only required
+      when mutating registrations and subscriptions (like what
       :meth:`zope.interface.interfaces.IComponents.registerUtility` does).
       This use pattern makes it an ideal candidate to be a
       :class:`~persistent.list.PersistentList`.
+
     _leafSequenceType = tuple
       This is the type used for the leaf sequences of subscribers.
       It could be set to a ``PersistentList`` to avoid many unnecessary data
-      loads when subscribers aren't being used. Mutation operations are directed
-      through :meth:`_addValueToLeaf` and :meth:`_removeValueFromLeaf`; if you use
-      a mutable type, you'll need to override those.
+      loads when subscribers aren't being used. Mutation operations are
+      directed through :meth:`_addValueToLeaf` and
+      :meth:`_removeValueFromLeaf`; if you use a mutable type, you'll need to
+      override those.
+
     _mappingType = dict
-      This is the mutable mapping type used for the keyed mappings.
-      A :class:`~persistent.mapping.PersistentMapping`
-      could be used to help reduce the number of data loads when the registry is large
-      and parts of it are rarely used. Further reductions in data loads can come from
-      using a :class:`~BTrees.OOBTree.OOBTree`, but care is required
-      to be sure that all required/provided
-      values are fully ordered (e.g., no required or provided values that are classes
-      can be used).
+      This is the mutable mapping type used for the keyed mappings.  A
+      :class:`~persistent.mapping.PersistentMapping` could be used to help
+      reduce the number of data loads when the registry is large and parts of
+      it are rarely used. Further reductions in data loads can come from using
+      a :class:`~BTrees.OOBTree.OOBTree`, but care is required to be sure that
+      all required/provided values are fully ordered (e.g., no required or
+      provided values that are classes can be used).
+
     _providedType = dict
       This is the mutable mapping type used for the ``_provided`` mapping.
       This is separate from the generic mapping type because the values
@@ -107,9 +110,10 @@ class BaseAdapterRegistry(object):
       The same caveats regarding key types
       apply as for ``_mappingType``.
 
-    It is possible to also set these on an instance, but because of the need to
-    potentially also override :meth:`_addValueToLeaf` and :meth:`_removeValueFromLeaf`,
-    this may be less useful in a persistent scenario; using a subclass is recommended.
+    It is possible to also set these on an instance, but because of the need
+    to potentially also override :meth:`_addValueToLeaf` and
+    :meth:`_removeValueFromLeaf`, this may be less useful in a persistent
+    scenario; using a subclass is recommended.
 
     .. versionchanged:: 5.3.0
         Add support for customizing the way internal data
@@ -210,18 +214,20 @@ class BaseAdapterRegistry(object):
         Add the value *new_item* to the *existing_leaf_sequence*, which may
         be ``None``.
 
-        Subclasses that redefine `_leafSequenceType` should override this method.
+        Subclasses that redefine `_leafSequenceType` should override this
+        method.
 
         :param existing_leaf_sequence:
             If *existing_leaf_sequence* is not *None*, it will be an instance
-            of `_leafSequenceType`. (Unless the object has been unpickled
-            from an old pickle and the class definition has changed, in which case
-            it may be an instance of a previous definition, commonly a `tuple`.)
+            of `_leafSequenceType`. (Unless the object has been unpickled from
+            an old pickle and the class definition has changed, in which case
+            it may be an instance of a previous definition, commonly a
+            `tuple`.)
 
         :return:
            This method returns the new value to be stored. It may mutate the
-           sequence in place if it was not ``None`` and the type is mutable, but
-           it must also return it.
+           sequence in place if it was not ``None`` and the type is mutable,
+           but it must also return it.
 
         .. versionadded:: 5.3.0
         """
@@ -262,7 +268,7 @@ class BaseAdapterRegistry(object):
         self._v_lookup.changed(originally_changed)
 
     def register(self, required, provided, name, value):
-        if not isinstance(name, STRING_TYPES):
+        if not isinstance(name, str):
             raise ValueError('name is not a string')
         if value is None:
             self.unregister(required, provided, name, value)
@@ -318,7 +324,7 @@ class BaseAdapterRegistry(object):
 
         return components.get(name)
 
-    def registered(self, required, provided, name=u''):
+    def registered(self, required, provided, name=''):
         return self._find_leaf(
             self._adapters,
             required,
@@ -334,14 +340,13 @@ class BaseAdapterRegistry(object):
         else:
             for k, v in components.items():
                 new_parent_k = parent_k + (k,)
-                for x, y in cls._allKeys(v, i - 1, new_parent_k):
-                    yield x, y
+                yield from cls._allKeys(v, i - 1, new_parent_k)
 
     def _all_entries(self, byorder):
         # Recurse through the mapping levels of the `byorder` sequence,
-        # reconstructing a flattened sequence of ``(required, provided, name, value)``
-        # tuples that can be used to reconstruct the sequence with the appropriate
-        # registration methods.
+        # reconstructing a flattened sequence of ``(required, provided, name,
+        # value)`` tuples that can be used to reconstruct the sequence with
+        # the appropriate registration methods.
         #
         # Locally reference the `byorder` data; it might be replaced while
         # this method is running (see ``rebuild``).
@@ -366,8 +371,7 @@ class BaseAdapterRegistry(object):
 
         .. versionadded:: 5.3.0
         """
-        for t in self._all_entries(self._adapters):
-            yield t
+        yield from self._all_entries(self._adapters)
 
     def unregister(self, required, provided, name, value=None):
         required = tuple([_convert_None_to_Interface(r) for r in required])
@@ -419,7 +423,7 @@ class BaseAdapterRegistry(object):
 
     def subscribe(self, required, provided, value):
         required = tuple([_convert_None_to_Interface(r) for r in required])
-        name = u''
+        name = ''
         order = len(required)
         byorder = self._subscribers
         while len(byorder) <= order:
@@ -449,7 +453,7 @@ class BaseAdapterRegistry(object):
             self._subscribers,
             required,
             provided,
-            u''
+            ''
         ) or ()
         return subscriber if subscriber in subscribers else None
 
@@ -464,7 +468,9 @@ class BaseAdapterRegistry(object):
 
         .. versionadded:: 5.3.0
         """
-        for required, provided, _name, value in self._all_entries(self._subscribers):
+        for required, provided, _name, value in self._all_entries(
+            self._subscribers,
+        ):
             for v in value:
                 yield (required, provided, v)
 
@@ -486,7 +492,7 @@ class BaseAdapterRegistry(object):
             lookups.append((components, k))
             components = d
 
-        old = components.get(u'')
+        old = components.get('')
         if not old:
             # this is belt-and-suspenders against the failure of cleanup below
             return  # pragma: no cover
@@ -509,7 +515,7 @@ class BaseAdapterRegistry(object):
             return
 
         if new:
-            components[u''] = new
+            components[''] = new
         else:
             # Instead of setting components[u''] = new, we clean out
             # empty containers, since we don't want our keys to
@@ -517,7 +523,7 @@ class BaseAdapterRegistry(object):
             # is often a problem when an interface is slated for
             # removal; a hold-over entry in the registry can make it
             # difficult to remove such interfaces.
-            del components[u'']
+            del components['']
             for comp, k in reversed(lookups):
                 d = comp[k]
                 if d:
@@ -573,7 +579,6 @@ class BaseAdapterRegistry(object):
         registrations = buffer(registrations)
         subscriptions = buffer(subscriptions)
 
-
         # Replace the base data structures as well as _v_lookup.
         self.__init__(self.__bases__)
         # Re-register everything previously registered and subscribed.
@@ -587,12 +592,13 @@ class BaseAdapterRegistry(object):
         # part of passing that notification to the change of objects.)
         for args in registrations:
             self.register(*args)
+
         for args in subscriptions:
             self.subscribe(*args)
 
-    # XXX hack to fake out twisted's use of a private api.  We need to get them
-    # to use the new registered method.
-    def get(self, _): # pragma: no cover
+    # XXX hack to fake out twisted's use of a private api.
+    # We need to get them to use the new registered method.
+    def get(self, _):  # pragma: no cover
         class XXXTwistedFakeOut:
             selfImplied = {}
         return XXXTwistedFakeOut
@@ -600,8 +606,9 @@ class BaseAdapterRegistry(object):
 
 _not_in_mapping = object()
 
+
 @_use_c_impl
-class LookupBase(object):
+class LookupBase:
 
     def __init__(self):
         self._cache = {}
@@ -626,8 +633,8 @@ class LookupBase(object):
             cache = c
         return cache
 
-    def lookup(self, required, provided, name=u'', default=None):
-        if not isinstance(name, STRING_TYPES):
+    def lookup(self, required, provided, name='', default=None):
+        if not isinstance(name, str):
             raise ValueError('name is not a string')
         cache = self._getcache(provided, name)
         required = tuple(required)
@@ -648,8 +655,8 @@ class LookupBase(object):
 
         return result
 
-    def lookup1(self, required, provided, name=u'', default=None):
-        if not isinstance(name, STRING_TYPES):
+    def lookup1(self, required, provided, name='', default=None):
+        if not isinstance(name, str):
             raise ValueError('name is not a string')
         cache = self._getcache(provided, name)
         result = cache.get(required, _not_in_mapping)
@@ -661,11 +668,11 @@ class LookupBase(object):
 
         return result
 
-    def queryAdapter(self, object, provided, name=u'', default=None):
+    def queryAdapter(self, object, provided, name='', default=None):
         return self.adapter_hook(provided, object, name, default)
 
-    def adapter_hook(self, provided, object, name=u'', default=None):
-        if not isinstance(name, STRING_TYPES):
+    def adapter_hook(self, provided, object, name='', default=None):
+        if not isinstance(name, str):
             raise ValueError('name is not a string')
         required = providedBy(object)
         cache = self._getcache(provided, name)
@@ -696,7 +703,6 @@ class LookupBase(object):
 
         return result
 
-
     def subscriptions(self, required, provided):
         cache = self._scache.get(provided)
         if cache is None:
@@ -713,52 +719,60 @@ class LookupBase(object):
 
 
 @_use_c_impl
-class VerifyingBase(LookupBaseFallback):
+class VerifyingBase(LookupBaseFallback):  # noqa F821
     # Mixin for lookups against registries which "chain" upwards, and
     # whose lookups invalidate their own caches whenever a parent registry
     # bumps its own '_generation' counter.  E.g., used by
     # zope.component.persistentregistry
 
     def changed(self, originally_changed):
-        LookupBaseFallback.changed(self, originally_changed)
+        LookupBaseFallback.changed(self, originally_changed)  # noqa F821
         self._verify_ro = self._registry.ro[1:]
         self._verify_generations = [r._generation for r in self._verify_ro]
 
     def _verify(self):
-        if ([r._generation for r in self._verify_ro]
-            != self._verify_generations):
+        if (
+            [
+                r._generation for r in self._verify_ro
+            ] != self._verify_generations
+        ):
             self.changed(None)
 
     def _getcache(self, provided, name):
         self._verify()
-        return LookupBaseFallback._getcache(self, provided, name)
+        return LookupBaseFallback._getcache(  # noqa F821
+            self, provided, name,
+        )
 
     def lookupAll(self, required, provided):
         self._verify()
-        return LookupBaseFallback.lookupAll(self, required, provided)
+        return LookupBaseFallback.lookupAll(  # noqa F821
+            self, required, provided,
+        )
 
     def subscriptions(self, required, provided):
         self._verify()
-        return LookupBaseFallback.subscriptions(self, required, provided)
+        return LookupBaseFallback.subscriptions(  # noqa F821
+            self, required, provided,
+        )
 
 
-class AdapterLookupBase(object):
+class AdapterLookupBase:
 
     def __init__(self, registry):
         self._registry = registry
         self._required = {}
         self.init_extendors()
-        super(AdapterLookupBase, self).__init__()
+        super().__init__()
 
     def changed(self, ignored=None):
-        super(AdapterLookupBase, self).changed(None)
+        super().changed(None)
         for r in self._required.keys():
             r = r()
             if r is not None:
                 r.unsubscribe(self)
         self._required.clear()
 
-
     # Extendors
     # ---------
 
@@ -781,7 +795,7 @@ class AdapterLookupBase(object):
     # the interface's __iro__ has changed.  This is unlikely enough that
     # we'll take our chances for now.
 
-    def init_extendors(self):
+    def init_extendors(self):  # noqa E301
         self._extendors = {}
         for p in self._registry._provided:
             self.add_extendor(p)
@@ -791,12 +805,14 @@ class AdapterLookupBase(object):
         for i in provided.__iro__:
             extendors = _extendors.get(i, ())
             _extendors[i] = (
-                [e for e in extendors if provided.isOrExtends(e)]
-                +
-                [provided]
-                +
-                [e for e in extendors if not provided.isOrExtends(e)]
-                )
+                [
+                    e for e in extendors if provided.isOrExtends(e)
+                ] + [
+                    provided
+                ] + [
+                    e for e in extendors if not provided.isOrExtends(e)
+                ]
+            )
 
     def remove_extendor(self, provided):
         _extendors = self._extendors
@@ -804,7 +820,6 @@ class AdapterLookupBase(object):
             _extendors[i] = [e for e in _extendors.get(i, ())
                              if e != provided]
 
-
     def _subscribe(self, *required):
         _refs = self._required
         for r in required:
@@ -813,7 +828,7 @@ class AdapterLookupBase(object):
                 r.subscribe(self)
                 _refs[ref] = 1
 
-    def _uncached_lookup(self, required, provided, name=u''):
+    def _uncached_lookup(self, required, provided, name=''):
         required = tuple(required)
         result = None
         order = len(required)
@@ -836,12 +851,14 @@ class AdapterLookupBase(object):
 
         return result
 
-    def queryMultiAdapter(self, objects, provided, name=u'', default=None):
+    def queryMultiAdapter(self, objects, provided, name='', default=None):
         factory = self.lookup([providedBy(o) for o in objects], provided, name)
         if factory is None:
             return default
 
-        result = factory(*[o.__self__ if isinstance(o, super) else o for o in objects])
+        result = factory(*[
+            o.__self__ if isinstance(o, super) else o for o in objects
+        ])
         if result is None:
             return default
 
@@ -884,7 +901,7 @@ class AdapterLookupBase(object):
                 if extendors is None:
                     continue
 
-            _subscriptions(byorder[order], required, extendors, u'',
+            _subscriptions(byorder[order], required, extendors, '',
                            result, 0, order)
 
         self._subscribe(*required)
@@ -892,7 +909,9 @@ class AdapterLookupBase(object):
         return result
 
     def subscribers(self, objects, provided):
-        subscriptions = self.subscriptions([providedBy(o) for o in objects], provided)
+        subscriptions = self.subscriptions(
+            [providedBy(o) for o in objects], provided
+        )
         if provided is None:
             result = ()
             for subscription in subscriptions:
@@ -905,9 +924,11 @@ class AdapterLookupBase(object):
                     result.append(subscriber)
         return result
 
+
 class AdapterLookup(AdapterLookupBase, LookupBase):
     pass
 
+
 @implementer(IAdapterRegistry)
 class AdapterRegistry(BaseAdapterRegistry):
     """
@@ -922,7 +943,7 @@ class AdapterRegistry(BaseAdapterRegistry):
         # we need to keep track of our invalidating subregistries.
         self._v_subregistries = weakref.WeakKeyDictionary()
 
-        super(AdapterRegistry, self).__init__(bases)
+        super().__init__(bases)
 
     def _addSubregistry(self, r):
         self._v_subregistries[r] = 1
@@ -940,10 +961,10 @@ class AdapterRegistry(BaseAdapterRegistry):
             if r not in old:
                 r._addSubregistry(self)
 
-        super(AdapterRegistry, self)._setBases(bases)
+        super()._setBases(bases)
 
     def changed(self, originally_changed):
-        super(AdapterRegistry, self).changed(originally_changed)
+        super().changed(originally_changed)
 
         for sub in self._v_subregistries.keys():
             sub.changed(originally_changed)
@@ -952,6 +973,7 @@ class AdapterRegistry(BaseAdapterRegistry):
 class VerifyingAdapterLookup(AdapterLookupBase, VerifyingBase):
     pass
 
+
 @implementer(IAdapterRegistry)
 class VerifyingAdapterRegistry(BaseAdapterRegistry):
     """
@@ -960,13 +982,15 @@ class VerifyingAdapterRegistry(BaseAdapterRegistry):
 
     LookupClass = VerifyingAdapterLookup
 
+
 def _convert_None_to_Interface(x):
     if x is None:
         return Interface
     else:
         return x
 
-def _lookup(components, specs, provided, name, i, l):
+
+def _lookup(components, specs, provided, name, i, l):  # noqa: E741
     # this function is called very often.
     # The components.get in loops is executed 100 of 1000s times.
     # by loading get into a local variable the bytecode
@@ -976,7 +1000,7 @@ def _lookup(components, specs, provided, name, i, l):
         for spec in specs[i].__sro__:
             comps = components_get(spec)
             if comps:
-                r = _lookup(comps, specs, provided, name, i+1, l)
+                r = _lookup(comps, specs, provided, name, i + 1, l)
                 if r is not None:
                     return r
     else:
@@ -989,26 +1013,32 @@ def _lookup(components, specs, provided, name, i, l):
 
     return None
 
-def _lookupAll(components, specs, provided, result, i, l):
+
+def _lookupAll(components, specs, provided, result, i, l):  # noqa: E741
     components_get = components.get  # see _lookup above
     if i < l:
         for spec in reversed(specs[i].__sro__):
             comps = components_get(spec)
             if comps:
-                _lookupAll(comps, specs, provided, result, i+1, l)
+                _lookupAll(comps, specs, provided, result, i + 1, l)
     else:
         for iface in reversed(provided):
             comps = components_get(iface)
             if comps:
                 result.update(comps)
 
-def _subscriptions(components, specs, provided, name, result, i, l):
+
+def _subscriptions(
+    components, specs, provided, name, result, i, l  # noqa: E741
+):
     components_get = components.get  # see _lookup above
     if i < l:
         for spec in reversed(specs[i].__sro__):
             comps = components_get(spec)
             if comps:
-                _subscriptions(comps, specs, provided, name, result, i+1, l)
+                _subscriptions(
+                    comps, specs, provided, name, result, i + 1, l
+                )
     else:
         for iface in reversed(provided):
             comps = components_get(iface)
